/**
 * Copyright 2002, 2013 IBM Corp.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * 
 *  Author: Sami Salkosuo, sami.salkosuo@fi.ibm.com
 */
package clenotes;

import clenotes.Command;
import clenotes.CommandLineArguments;
import clenotes.Configuration;
import clenotes.Option;
import clenotes.commands.Appointments;
import clenotes.commands.List;
import clenotes.commands.MailDBInfo;
import clenotes.commands.ReadMail;
import clenotes.commands.Replicate;
import clenotes.commands.Search;
import clenotes.commands.Send;
import clenotes.commands.Today;
import com.google.common.base.Objects;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Set;
import lotus.domino.NotesFactory;
import lotus.domino.Session;
import org.eclipse.xtext.xbase.lib.Exceptions;
import org.eclipse.xtext.xbase.lib.InputOutput;

@SuppressWarnings("all")
public class CLENotes implements Runnable {
  private int returnCode = 0;
  
  private Session notesSession = null;
  
  public CLENotes() {
  }
  
  public void run() {
    try {
      boolean _verifyOptionsAndCommands = this.verifyOptionsAndCommands();
      boolean _not = (!_verifyOptionsAndCommands);
      if (_not) {
        int _minus = (-1);
        this.returnCode = _minus;
        return;
      }
      LinkedHashMap<Object,Object> commandMap = CommandLineArguments.commandMap;
      boolean _hasOption = CommandLineArguments.hasOption("version");
      if (_hasOption) {
        this.option_Version();
        return;
      }
      String password = CommandLineArguments.getValue("password");
      String serverHost = null;
      boolean _notEquals = (!Objects.equal(password, null));
      if (_notEquals) {
        Session _createSession = NotesFactory.createSession(serverHost, ((String) null), password);
        this.notesSession = _createSession;
      } else {
        Session _createSession_1 = NotesFactory.createSession();
        this.notesSession = _createSession_1;
      }
      boolean _isEmpty = commandMap.isEmpty();
      boolean _not_1 = (!_isEmpty);
      if (_not_1) {
        Set<Object> _keySet = commandMap.keySet();
        for (final Object cmdName : _keySet) {
          {
            Object _get = commandMap.get(cmdName);
            Command command = ((Command) _get);
            boolean _matched = false;
            if (!_matched) {
              if (Objects.equal(cmdName,"today")) {
                _matched=true;
                Today.execute(command, this.notesSession);
              }
            }
            if (!_matched) {
              if (Objects.equal(cmdName,"replicate")) {
                _matched=true;
                Replicate.execute(command, this.notesSession);
              }
            }
            if (!_matched) {
              if (Objects.equal(cmdName,"search")) {
                _matched=true;
                Search.execute(command, this.notesSession);
              }
            }
            if (!_matched) {
              if (Objects.equal(cmdName,"read")) {
                _matched=true;
                ReadMail.readLatestMail(command, this.notesSession);
              }
            }
            if (!_matched) {
              if (Objects.equal(cmdName,"list")) {
                _matched=true;
                List.execute(command, this.notesSession);
              }
            }
            if (!_matched) {
              if (Objects.equal(cmdName,"notes-version")) {
                _matched=true;
                this.command_NotesVersion();
              }
            }
            if (!_matched) {
              if (Objects.equal(cmdName,"send")) {
                _matched=true;
                Send.execute(command, this.notesSession);
              }
            }
            if (!_matched) {
              if (Objects.equal(cmdName,"appointments")) {
                _matched=true;
                Appointments.execute(command, this.notesSession);
              }
            }
            if (!_matched) {
              if (Objects.equal(cmdName,"maildbinfo")) {
                _matched=true;
                MailDBInfo.execute(command, this.notesSession);
              }
            }
          }
        }
      }
      this.notesSession.recycle();
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  public String option_Version() {
    String _xblockexpression = null;
    {
      String _plus = ("CLENotes      : " + Configuration.VERSION);
      InputOutput.<String>println(_plus);
      String _property = System.getProperty("java.version");
      String _plus_1 = ("Java          : " + _property);
      String _println = InputOutput.<String>println(_plus_1);
      _xblockexpression = (_println);
    }
    return _xblockexpression;
  }
  
  public String command_NotesVersion() {
    try {
      String _xblockexpression = null;
      {
        String prog = null;
        boolean _isOnServer = this.notesSession.isOnServer();
        if (_isOnServer) {
          prog = "Domino version: ";
        } else {
          prog = "Notes version : ";
        }
        InputOutput.<String>print(prog);
        String _notesVersion = this.notesSession.getNotesVersion();
        InputOutput.<String>print(_notesVersion);
        InputOutput.<String>print(" (");
        String _platform = this.notesSession.getPlatform();
        InputOutput.<String>print(_platform);
        InputOutput.<String>println(")");
        String _plus = ("CLENotes      : " + Configuration.VERSION);
        InputOutput.<String>println(_plus);
        String _property = System.getProperty("java.version");
        String _plus_1 = ("Java          : " + _property);
        String _println = InputOutput.<String>println(_plus_1);
        _xblockexpression = (_println);
      }
      return _xblockexpression;
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  public boolean verifyOptionsAndCommands() {
    boolean _xblockexpression = false;
    {
      boolean atLeastOneValid = false;
      Map<String,Option> optionMap = CommandLineArguments.globalOptionMap;
      Map<String,Option> optionMapConfig = Configuration.globalOptionMap;
      Set<String> _keySet = optionMap.keySet();
      for (final String key : _keySet) {
        boolean _containsKey = optionMapConfig.containsKey(key);
        if (_containsKey) {
          atLeastOneValid = true;
        } else {
          String _plus = ("Unknown option: " + key);
          InputOutput.<String>println(_plus);
        }
      }
      LinkedHashMap<Object,Object> commandMap = CommandLineArguments.commandMap;
      LinkedHashMap<Object,Object> commandMapConfig = Configuration.commandMap;
      Set<Object> _keySet_1 = commandMap.keySet();
      for (final Object key_1 : _keySet_1) {
        boolean _containsKey_1 = commandMapConfig.containsKey(key_1);
        if (_containsKey_1) {
          atLeastOneValid = true;
        } else {
          String _plus_1 = ("Unknown command: " + key_1);
          InputOutput.<String>println(_plus_1);
        }
      }
      _xblockexpression = (atLeastOneValid);
    }
    return _xblockexpression;
  }
  
  public int getReturnCode() {
    return this.returnCode;
  }
}
