/**
 * Copyright 2002, 2013 IBM Corp.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * 
 *  Author: Sami Salkosuo, sami.salkosuo@fi.ibm.com
 */
package clenotes.commands;

import clenotes.Command;
import clenotes.Logger;
import clenotes.utils.DominoUtils;
import com.google.common.base.Objects;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.Vector;
import lotus.domino.Database;
import lotus.domino.DateTime;
import lotus.domino.Document;
import lotus.domino.DocumentCollection;
import lotus.domino.Session;
import org.eclipse.xtext.xbase.lib.CollectionLiterals;
import org.eclipse.xtext.xbase.lib.Exceptions;
import org.eclipse.xtext.xbase.lib.InputOutput;
import org.eclipse.xtext.xbase.lib.IntegerRange;

@SuppressWarnings("all")
public class Appointments {
  public static int execute(final Command cmd, final Session notesSession) {
    try {
      Database mailDb = DominoUtils.getMailDatabase(notesSession);
      boolean printRequired = cmd.hasOption("required");
      boolean printOptional = cmd.hasOption("optional");
      boolean printDesc = cmd.hasOption("desc");
      DateTime currentDateTime = notesSession.createDateTime("Today");
      currentDateTime.setNow();
      String searchAppointmentString = "Form = \"Appointment\"";
      DocumentCollection docCollection = null;
      boolean _hasOption = cmd.hasOption("sincedate");
      if (_hasOption) {
        String dateString = cmd.getOptionValue("sincedate");
        String[] dateStr = dateString.split("/");
        Calendar calendarDateTime = Calendar.getInstance();
        String _get = dateStr[2];
        int _parseInt = Integer.parseInt(_get);
        String _get_1 = dateStr[1];
        int _parseInt_1 = Integer.parseInt(_get_1);
        int _minus = (_parseInt_1 - 1);
        String _get_2 = dateStr[0];
        int _parseInt_2 = Integer.parseInt(_get_2);
        calendarDateTime.set(_parseInt, _minus, _parseInt_2, 0, 0, 1);
        DateTime cutOffDate = notesSession.createDateTime(calendarDateTime);
        String _get_3 = dateStr[2];
        String _plus = ("Form = \"Appointment\" & StartDateTime >= @Date( " + _get_3);
        String _plus_1 = (_plus + " ;");
        String _get_4 = dateStr[1];
        String _plus_2 = (_plus_1 + _get_4);
        String _plus_3 = (_plus_2 + "; ");
        String _get_5 = dateStr[0];
        String _plus_4 = (_plus_3 + _get_5);
        String _plus_5 = (_plus_4 + ") ");
        searchAppointmentString = _plus_5;
        DocumentCollection _search = mailDb.search(searchAppointmentString);
        docCollection = _search;
        Document doc = docCollection.getFirstDocument();
        int index1 = 1;
        boolean _notEquals = (!Objects.equal(doc, null));
        boolean _while = _notEquals;
        while (_while) {
          {
            Vector appointmentType = doc.getItemValue("AppointmentType");
            String appointmentFrom = doc.getItemValueString("From");
            String location = doc.getItemValueString("Location");
            String room = doc.getItemValueString("Room");
            Vector startDateTimeList = doc.getItemValue("StartDateTime");
            Vector endDateTimeList = doc.getItemValue("EndDateTime");
            String subject = doc.getItemValueString("Subject");
            int index = 0;
            for (final Object _startDateTime : startDateTimeList) {
              {
                DateTime startDateTime = ((DateTime) _startDateTime);
                int _timeDifference = startDateTime.timeDifference(cutOffDate);
                boolean _lessThan = (_timeDifference < 0);
                if (_lessThan) {
                  int _plus_6 = (index + 1);
                  index = _plus_6;
                } else {
                  Object _get_6 = endDateTimeList.get(index);
                  DateTime endDateTime = ((DateTime) _get_6);
                  String _plus_7 = ("[" + Integer.valueOf(index1));
                  String _plus_8 = (_plus_7 + "] ");
                  String _plus_9 = (_plus_8 + subject);
                  InputOutput.<String>println(_plus_9);
                  String _plus_10 = ("  From    : " + appointmentFrom);
                  InputOutput.<String>println(_plus_10);
                  if (printRequired) {
                    Vector requiredList = doc.getItemValue("AltRequiredNames");
                    String names = "";
                    for (final Object n : requiredList) {
                      String _plus_11 = (names + n);
                      String _plus_12 = (_plus_11 + ",");
                      names = _plus_12;
                    }
                    int _length = names.length();
                    int _minus_1 = (_length - 1);
                    String _substring = names.substring(0, _minus_1);
                    String _plus_13 = ("  Required: " + _substring);
                    InputOutput.<String>println(_plus_13);
                  }
                  if (printOptional) {
                    Vector optionalList = doc.getItemValue("AltOptionalNames");
                    String names_1 = "";
                    for (final Object n_1 : optionalList) {
                      String _plus_14 = (names_1 + n_1);
                      String _plus_15 = (_plus_14 + ",");
                      names_1 = _plus_15;
                    }
                    int _length_1 = names_1.length();
                    int _minus_2 = (_length_1 - 1);
                    String _substring_1 = names_1.substring(0, _minus_2);
                    String _plus_16 = ("  Optional: " + _substring_1);
                    InputOutput.<String>println(_plus_16);
                  }
                  String desc = null;
                  if (printDesc) {
                    String _itemValueString = doc.getItemValueString("Body");
                    desc = _itemValueString;
                  }
                  String filling = "";
                  if (printDesc) {
                    filling = "   ";
                  }
                  String _plus_17 = ("  Start   " + filling);
                  String _plus_18 = (_plus_17 + ": ");
                  String _plus_19 = (_plus_18 + startDateTime);
                  InputOutput.<String>println(_plus_19);
                  String _plus_20 = ("  End     " + filling);
                  String _plus_21 = (_plus_20 + ": ");
                  String _plus_22 = (_plus_21 + endDateTime);
                  InputOutput.<String>println(_plus_22);
                  String _plus_23 = ("  Location" + filling);
                  String _plus_24 = (_plus_23 + ": ");
                  String _plus_25 = (_plus_24 + location);
                  InputOutput.<String>println(_plus_25);
                  String _plus_26 = ("  Room    " + filling);
                  String _plus_27 = (_plus_26 + ": ");
                  String _plus_28 = (_plus_27 + room);
                  InputOutput.<String>println(_plus_28);
                  if (printDesc) {
                    String _plus_29 = ("  Description: " + desc);
                    InputOutput.<String>println(_plus_29);
                  }
                  int _plus_30 = (index1 + 1);
                  index1 = _plus_30;
                  int _plus_31 = (index + 1);
                  index = _plus_31;
                }
              }
            }
            Document _nextDocument = docCollection.getNextDocument();
            doc = _nextDocument;
          }
          boolean _notEquals_1 = (!Objects.equal(doc, null));
          _while = _notEquals_1;
        }
        return 0;
      } else {
        DocumentCollection _search_1 = mailDb.search(searchAppointmentString);
        docCollection = _search_1;
      }
      int matches = docCollection.getCount();
      ArrayList<String> weekDates = CollectionLiterals.<String>newArrayList();
      boolean _hasOption_1 = cmd.hasOption("week");
      if (_hasOption_1) {
        String _dateOnly = currentDateTime.getDateOnly();
        weekDates.add(_dateOnly);
        IntegerRange _upTo = new IntegerRange(0, 6);
        for (final Integer i : _upTo) {
          {
            DateTime newDateTime = notesSession.createDateTime("Today");
            newDateTime.setNow();
            int _plus_6 = ((i).intValue() + 1);
            newDateTime.adjustDay(_plus_6);
            String _dateOnly_1 = newDateTime.getDateOnly();
            weekDates.add(_dateOnly_1);
          }
        }
      }
      Document doc_1 = docCollection.getLastDocument();
      int index1_1 = 1;
      boolean _notEquals_1 = (!Objects.equal(doc_1, null));
      boolean _while_1 = _notEquals_1;
      while (_while_1) {
        {
          Vector appointmentType = doc_1.getItemValue("AppointmentType");
          String appointmentFrom = doc_1.getItemValueString("From");
          String location = doc_1.getItemValueString("Location");
          String room = doc_1.getItemValueString("Room");
          Vector startDateTimeList = doc_1.getItemValue("StartDateTime");
          Vector endDateTimeList = doc_1.getItemValue("EndDateTime");
          int index = 0;
          for (final Object _start : startDateTimeList) {
            {
              DateTime start = ((DateTime) _start);
              int difference = currentDateTime.timeDifference(start);
              boolean _hasOption_2 = cmd.hasOption("today");
              if (_hasOption_2) {
                String dateText1 = currentDateTime.getDateOnly();
                String dateText2 = start.getDateOnly();
                String _plus_6 = ("today option in appointments: " + dateText1);
                String _plus_7 = (_plus_6 + " ");
                String _plus_8 = (_plus_7 + dateText2);
                Logger.log(_plus_8);
                boolean _equals = Objects.equal(dateText1, dateText2);
                if (_equals) {
                  int _minus_1 = (-1);
                  difference = _minus_1;
                } else {
                  difference = 1;
                }
              }
              boolean _hasOption_3 = cmd.hasOption("week");
              if (_hasOption_3) {
                String dateText1_1 = start.getDateOnly();
                boolean _contains = weekDates.contains(dateText1_1);
                if (_contains) {
                  int _minus_2 = (-1);
                  difference = _minus_2;
                } else {
                  difference = 1;
                }
              }
              boolean _or = false;
              boolean _hasOption_4 = cmd.hasOption("sincedate");
              if (_hasOption_4) {
                _or = true;
              } else {
                boolean _lessThan = (difference < 0);
                _or = (_hasOption_4 || _lessThan);
              }
              if (_or) {
                Object end = endDateTimeList.get(index);
                String subject = doc_1.getItemValueString("Subject");
                Date _date = new Date();
                DateTime _currentDateTime = notesSession.createDateTime(_date);
                String _plus_9 = ("[" + Integer.valueOf(index1_1));
                String _plus_10 = (_plus_9 + "] ");
                String _plus_11 = (_plus_10 + subject);
                InputOutput.<String>println(_plus_11);
                String _plus_12 = ("  From    : " + appointmentFrom);
                InputOutput.<String>println(_plus_12);
                if (printRequired) {
                  Vector requiredList = doc_1.getItemValue("AltRequiredNames");
                  String names = "";
                  for (final Object n : requiredList) {
                    String _plus_13 = (names + n);
                    String _plus_14 = (_plus_13 + ",");
                    names = _plus_14;
                  }
                  int _length = names.length();
                  int _minus_3 = (_length - 1);
                  String _substring = names.substring(0, _minus_3);
                  String _plus_15 = ("  Required: " + _substring);
                  InputOutput.<String>println(_plus_15);
                }
                if (printOptional) {
                  Vector optionalList = doc_1.getItemValue("AltOptionalNames");
                  String names_1 = "";
                  for (final Object n_1 : optionalList) {
                    String _plus_16 = (names_1 + n_1);
                    String _plus_17 = (_plus_16 + ",");
                    names_1 = _plus_17;
                  }
                  int _length_1 = names_1.length();
                  int _minus_4 = (_length_1 - 1);
                  String _substring_1 = names_1.substring(0, _minus_4);
                  String _plus_18 = ("  Optional: " + _substring_1);
                  InputOutput.<String>println(_plus_18);
                }
                String desc = null;
                if (printDesc) {
                  String _itemValueString = doc_1.getItemValueString("Body");
                  desc = _itemValueString;
                }
                String filling = "";
                if (printDesc) {
                  filling = "   ";
                }
                String _plus_19 = ("  Start   " + filling);
                String _plus_20 = (_plus_19 + ": ");
                String _plus_21 = (_plus_20 + start);
                InputOutput.<String>println(_plus_21);
                String _plus_22 = ("  End     " + filling);
                String _plus_23 = (_plus_22 + ": ");
                String _plus_24 = (_plus_23 + end);
                InputOutput.<String>println(_plus_24);
                String _plus_25 = ("  Location" + filling);
                String _plus_26 = (_plus_25 + ": ");
                String _plus_27 = (_plus_26 + location);
                InputOutput.<String>println(_plus_27);
                String _plus_28 = ("  Room    " + filling);
                String _plus_29 = (_plus_28 + ": ");
                String _plus_30 = (_plus_29 + room);
                InputOutput.<String>println(_plus_30);
                if (printDesc) {
                  String _plus_31 = ("  Description: " + desc);
                  InputOutput.<String>println(_plus_31);
                }
                int _plus_32 = (index1_1 + 1);
                index1_1 = _plus_32;
              }
              int _plus_33 = (index + 1);
              index = _plus_33;
            }
          }
          Document _prevDocument = docCollection.getPrevDocument();
          doc_1 = _prevDocument;
        }
        boolean _notEquals_2 = (!Objects.equal(doc_1, null));
        _while_1 = _notEquals_2;
      }
      return 0;
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
}
