/**
 * Copyright 2002, 2013 IBM Corp.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * 
 *  Author: Sami Salkosuo, sami.salkosuo@fi.ibm.com
 */
package clenotes.commands;

import clenotes.Command;
import clenotes.Configuration;
import clenotes.Option;
import clenotes.utils.ExtensionMethods;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import lotus.domino.Session;
import org.eclipse.xtext.xbase.lib.CollectionLiterals;
import org.eclipse.xtext.xbase.lib.Conversions;
import org.eclipse.xtext.xbase.lib.InputOutput;
import org.eclipse.xtext.xbase.lib.IterableExtensions;
import org.eclipse.xtext.xbase.lib.Procedures.Procedure2;

@SuppressWarnings("all")
public class Help {
  private final static int OPT_NAME_SECTION_LENGTH = 28;
  
  private final static int OPT_DESC_SECTION_LENGTH = 42;
  
  public static int execute(final Command cmd, final Session notesSession) {
    int rv = 0;
    InputOutput.<String>println("Usage: clenotes.cmd [global-options] [cmd [cmd-options]]");
    final Map<String,Option> globalOptionMap = Configuration.globalOptionMap;
    InputOutput.<String>println("Usage: clenotes.cmd [OPTIONS] [CMD [CMD-OPTIONS] [CMD ...] ]");
    InputOutput.println();
    InputOutput.<String>println("Global options (common for one or more commands):");
    final String goptIndent = "  --";
    Help.printOptions(goptIndent, globalOptionMap);
    InputOutput.println();
    InputOutput.<String>println("Commands:");
    final LinkedHashMap<Object,Object> commandMap = Configuration.commandMap;
    final Set<Object> commandNames = commandMap.keySet();
    final String commandIndent = "  ";
    for (final Object name : commandNames) {
      {
        Object _get = commandMap.get(name);
        Command command = ((Command) _get);
        String _name = command.getName();
        final String cmdName = (commandIndent + _name);
        String _description = command.getDescription();
        List<String> desc = ((List<String>)Conversions.doWrapArray(_description.split(" ")));
        int _length = cmdName.length();
        final int appendSpaces = (Help.OPT_NAME_SECTION_LENGTH - _length);
        final String appendString = ExtensionMethods.times(" ", appendSpaces);
        String _plus = (cmdName + appendString);
        Help.printHelp(_plus, desc);
        Map<String,Option> cmdOptions = command.getOptionMap();
        Help.printOptions("    --", cmdOptions);
      }
    }
    return rv;
  }
  
  private static void printOptions(final String indent, final Map<String,Option> optionMap) {
    final Set<String> optionNames = optionMap.keySet();
    for (final String name : optionNames) {
      {
        final Option option = optionMap.get(name);
        final String optName = option.getName();
        String _description = option.getDescription();
        final String[] optDesc = _description.split(" ");
        final boolean hasValue = option.isMandatoryValue();
        String _plus = (indent + optName);
        String _xifexpression = null;
        if (hasValue) {
          _xifexpression = "=ARG";
        } else {
          _xifexpression = "";
        }
        String descStr = (_plus + _xifexpression);
        int _length = descStr.length();
        final int appendSpaces = (Help.OPT_NAME_SECTION_LENGTH - _length);
        final String appendString = ExtensionMethods.times(" ", appendSpaces);
        String _plus_1 = (descStr + appendString);
        descStr = _plus_1;
        Help.printHelp(descStr, ((List<String>)Conversions.doWrapArray(optDesc)));
      }
    }
  }
  
  private static void printHelp(final String name, final List<String> desc) {
    final String indentation = ExtensionMethods.times(" ", Help.OPT_NAME_SECTION_LENGTH);
    List<String> descLines = CollectionLiterals.<String>newArrayList();
    StringBuffer _stringBuffer = new StringBuffer();
    StringBuffer sb = _stringBuffer;
    for (final String word : desc) {
      {
        sb.append(word);
        int _length = sb.length();
        boolean _greaterThan = (_length > Help.OPT_DESC_SECTION_LENGTH);
        if (_greaterThan) {
          String _string = sb.toString();
          int _length_1 = sb.length();
          int _length_2 = word.length();
          int _minus = (_length_1 - _length_2);
          String _substring = _string.substring(0, _minus);
          descLines.add(_substring);
          StringBuffer _stringBuffer_1 = new StringBuffer();
          sb = _stringBuffer_1;
          sb.append(word);
        }
        sb.append(" ");
      }
    }
    String _string = sb.toString();
    String _trim = _string.trim();
    descLines.add(_trim);
    final Procedure2<String,Integer> _function = new Procedure2<String,Integer>() {
      public void apply(final String line, final Integer index) {
        boolean _equals = ((index).intValue() == 0);
        if (_equals) {
          String _plus = (name + line);
          InputOutput.<String>println(_plus);
        } else {
          String _plus_1 = (indentation + line);
          InputOutput.<String>println(_plus_1);
        }
      }
    };
    IterableExtensions.<String>forEach(descLines, _function);
  }
}
