/**
 * Copyright 2002, 2013 IBM Corp.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * 
 *  Author: Sami Salkosuo, sami.salkosuo@fi.ibm.com
 */
package clenotes.commands;

import clenotes.Command;
import clenotes.CommandLineArguments;
import clenotes.Logger;
import clenotes.utils.DominoUtils;
import lotus.domino.Database;
import lotus.domino.DbDirectory;
import lotus.domino.Name;
import lotus.domino.Session;
import org.eclipse.xtext.xbase.lib.Exceptions;
import org.eclipse.xtext.xbase.lib.InputOutput;
import org.eclipse.xtext.xbase.lib.StringExtensions;

@SuppressWarnings("all")
public class Replicate {
  public static int execute(final Command cmd, final Session notesSession) {
    try {
      DbDirectory dbDirectory = null;
      String databaseFile = cmd.getOptionValue("database");
      Database dominoDatabase = null;
      boolean _isNullOrEmpty = StringExtensions.isNullOrEmpty(databaseFile);
      if (_isNullOrEmpty) {
        Database _mailDatabase = DominoUtils.getMailDatabase(notesSession);
        dominoDatabase = _mailDatabase;
      } else {
        DbDirectory _dbDirectory = notesSession.getDbDirectory(null);
        dbDirectory = _dbDirectory;
        Database _openDatabase = DominoUtils.openDatabase(dbDirectory, databaseFile, null);
        dominoDatabase = _openDatabase;
      }
      String _title = dominoDatabase.getTitle();
      String _plus = ("Database to replicate: " + _title);
      Logger.log(_plus);
      String server = cmd.getOptionValue("server");
      String _plus_1 = ("Server: " + server);
      Logger.log(_plus_1);
      boolean _isNullOrEmpty_1 = StringExtensions.isNullOrEmpty(server);
      if (_isNullOrEmpty_1) {
        String _server = dominoDatabase.getServer();
        server = _server;
        String _plus_2 = ("Using replication server: " + server);
        InputOutput.<String>println(_plus_2);
      }
      String replicaId = cmd.getOptionValue("replica-id");
      boolean _isNullOrEmpty_2 = StringExtensions.isNullOrEmpty(replicaId);
      if (_isNullOrEmpty_2) {
        String _value = CommandLineArguments.getValue("replica-id");
        replicaId = _value;
      }
      boolean _isNullOrEmpty_3 = StringExtensions.isNullOrEmpty(replicaId);
      if (_isNullOrEmpty_3) {
        String _replicaID = dominoDatabase.getReplicaID();
        replicaId = _replicaID;
        String _plus_3 = ("Using Replica ID: " + replicaId);
        InputOutput.<String>println(_plus_3);
      }
      String dbFilePath = dominoDatabase.getFilePath();
      boolean _startsWith = server.startsWith("CN=");
      boolean _not = (!_startsWith);
      if (_not) {
        String _plus_4 = ("Changing server to canonical format: " + server);
        String _plus_5 = (_plus_4 + "...");
        Logger.log(_plus_5);
        Name _createName = notesSession.createName(server);
        String _canonical = _createName.getCanonical();
        server = _canonical;
        String _plus_6 = ("Changed server to canonical format: " + server);
        Logger.log(_plus_6);
      }
      String _plus_7 = ("Replicate " + dbFilePath);
      String _plus_8 = (_plus_7 + " with server: ");
      String _plus_9 = (_plus_8 + server);
      Logger.log(_plus_9);
      int rValue = 0;
      boolean isReplicaDone = dominoDatabase.replicate(server);
      if (isReplicaDone) {
        String _title_1 = dominoDatabase.getTitle();
        String _plus_10 = ("Database " + _title_1);
        String _plus_11 = (_plus_10 + " replicated.");
        InputOutput.<String>println(_plus_11);
      } else {
        InputOutput.<String>println("[ERROR] Error occurred while replicating database.");
        int _minus = (-101);
        rValue = _minus;
      }
      return rValue;
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
}
