/*
 * Copyright 2002, 2013 IBM Corp.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.  
 *
 *  Author: Sami Salkosuo, sami.salkosuo@fi.ibm.com
*/
package clenotes.commands

import clenotes.Command
import clenotes.CommandLineArguments
import clenotes.utils.DominoUtils
import java.io.ByteArrayOutputStream
import java.io.File
import java.io.FileInputStream
import lotus.domino.DateTime
import lotus.domino.Document
import lotus.domino.DocumentCollection
import lotus.domino.Session

class Search {

	def static execute(Command cmd, Session notesSession) {

		var mailDb = DominoUtils::getMailDatabase(notesSession)

		var DateTime dt = notesSession.createDateTime("Yesterday")

		var adjustDay = CommandLineArguments::getValue("adjust-day")
		if (adjustDay != null) {
			dt.adjustDay(-Integer::parseInt(adjustDay))

		}

		//var DocumentCollection docCollection = mailDb.search("@All", dt)
		var subject = cmd.getOptionValue("subject")
		var sender = cmd.getOptionValue("from")
		var formula = cmd.getOptionValue("formula")
		var formulaFile = cmd.getOptionValue("formula-file")
		var fulltext = cmd.getOptionValue("fulltext")

		if (subject == null && sender == null && formula == null && formulaFile == null && fulltext == null) {
			println("[ERROR] Search option must be specified.")
			return -101
		}

		var String mailSearchString = null
		if (subject != null) {
			mailSearchString = '@Contains(Subject;"' + subject + '")'
		}

		if (sender != null) {
			mailSearchString = '@Contains(From;"' + sender + '") | @Contains(Principal;"' + sender + '")'
		}

		if (formulaFile != null) {

			//read formula from a file
			var file = new File(formulaFile)
			if (file.exists()) {
				var input = new FileInputStream(file)
				var output=new ByteArrayOutputStream
				var chr = input.read
				while (chr>-1) {
					output.write(chr)
					chr=input.read
				}
				input.close
				output.close
				formula = output.toString
			} else {
				println("[ERROR] File does not exist: " + file + ".")
			}
		}

		if (formula != null) {
			mailSearchString = formula
		}

		var DocumentCollection docCollection = null
		if (fulltext != null) {
			docCollection = mailDb.FTSearch(fulltext);
		} else {
			docCollection = mailDb.search(mailSearchString) //, dt, 0);
		}
		docCollection = DominoUtils::sortDocumentCollectionIfNecessary(docCollection, mailDb, cmd)

		var matches = docCollection.getCount()

		var readIndex = cmd.getOptionValue("read")
		if (readIndex == "*") {
			var n = 1
			var doc = docCollection.getNthDocument(n)
			while (doc != null) {
				var isDeleted = ReadMail::readMail(doc, cmd, notesSession)
				n = n + 1
				doc.recycle()
				doc = docCollection.getNthDocument(n)
			}
		} else {
			var _readIndex = -1
			if (readIndex != null) {
				_readIndex = Integer::parseInt(readIndex)
			}

			var values = DominoUtils::getMails(docCollection, cmd, _readIndex, false, notesSession)
			var numberOfMails = values.get(0)
			var outputTxt = values.get(1) as String
			var mailDoc = values.get(2) as Document

			if (mailDoc == null) {
				var txt = "mails"
				if(numberOfMails == 1) txt = "mail"
				println("Search returned " + numberOfMails + " " + txt + ".\r\n")
				println(outputTxt)

			} else {
				ReadMail::readMail(mailDoc, cmd, notesSession)

			}

		}

		return 0

	}
}
