/*
 * Copyright 2002, 2013 IBM Corp.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.  
 *
 *  Author: Sami Salkosuo, sami.salkosuo@fi.ibm.com
*/
package clenotes.commands

import clenotes.Command
import clenotes.CommandLineArguments
import clenotes.Logger
import clenotes.utils.DominoUtils
import lotus.domino.DateTime
import lotus.domino.Document
import lotus.domino.DocumentCollection
import lotus.domino.Session

class Today {

	def static execute(Command cmd, Session notesSession) {
		var mailDb = DominoUtils::getMailDatabase(notesSession)

		var DateTime dt = notesSession.createDateTime("Yesterday")

		var adjustDay = CommandLineArguments::getValue("adjust-day")
		if (adjustDay != null) {
			dt.adjustDay(-Integer::parseInt(adjustDay))

		}

		var DocumentCollection docCollection = mailDb.search("@All", dt)
		docCollection = DominoUtils::sortDocumentCollectionIfNecessary(docCollection, mailDb, cmd)

		
		//var matches = docCollection.getCount()
		//TODO: read index using list syntax: 45, 1:21, :21, 34: etc
		var readIndex = cmd.getOptionValue("read")

		if (readIndex != null && readIndex.equals("*")) {
			var n = 1
			var doc = docCollection.getNthDocument(n)
			while (doc != null) {
				ReadMail::readMail(doc, cmd,notesSession)
				n = n + 1
				doc.recycle()
				doc = docCollection.getNthDocument(n)

			}
		} else {

			//TODO: go through mails and print todays mails
			var _readIndex = -1
			if (readIndex != null) {
				_readIndex = Integer::parseInt(readIndex)
			}
			var values = DominoUtils::getMails(docCollection, cmd, _readIndex, false,notesSession)
			var numberOfMails = values.get(0)
			var outputTxt = values.get(1) as String
			var mailDoc = values.get(2) as Document

			//(numberOfMails,outputTxt,mailDoc)=getMails(docCollection,opts,cmdOptions=cmdOpts,docReadIndex=readIndex)  
			if (mailDoc == null) {
				var txt = "mails"
				if(numberOfMails == 1) txt = "mail"
				var adjustedDay = ""
				if (adjustDay != null) {
					adjustedDay = "-" + adjustDay

				}
				println(numberOfMails + " " + txt + " since yesterday" + adjustedDay + ".")
				println()
				println(outputTxt)

			} else {
				Logger::log("Reading mail... " + mailDoc.toString)
				ReadMail::readMail(mailDoc, cmd,notesSession)

			}
		}

		return 0

	}
}
